import Cookies from 'js-cookie';
import { SessionManager } from './SessionManager';
// const mockedSetCookie = setCookie as jest.MockedFunction<typeof setCookie>;
// const mockedGetCookie = getCookie as jest.MockedFunction<typeof getCookie>;
describe('SessionManager', function () {
    var manager;
    var envId = 'envId-12345';
    var user = {
        key: 'user-key-12345',
        email: 'test@test.com',
        name: 'Test User'
    };
    // const sessionIdentity: SessionIdentity = {
    //   sessionId: 'sessionId',
    //   userId: 'userId'
    // };
    var defaultPropertySession = {
        envId: envId,
        // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
        orgId: expect.any(String),
        // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
        projId: expect.any(String)
    };
    // const defaultUser: SLUser = {
    //   // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    //   key: expect.any(String)
    // };
    // const defaultSessionIdentity: SessionIdentity = {
    //   // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    //   sessionId: expect.any(String),
    //   // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    //   userId: expect.any(String)
    // };
    var idCookieName = "_sl_id.".concat(envId);
    var propsCookieName = "_sl_props.".concat(envId);
    beforeEach(function () {
        Cookies.remove(idCookieName);
        Cookies.remove(propsCookieName);
    });
    describe('constructor', function () {
        beforeEach(function () {
            manager = new SessionManager(envId);
        });
        it('should always setup a brand new property session with the envId', function () {
            var cookieProperties = JSON.parse(Cookies.get(propsCookieName) || '');
            expect(cookieProperties).toEqual(defaultPropertySession);
        });
        describe('when user defined', function () {
            beforeEach(function () {
                manager = new SessionManager(envId, user);
            });
            it('should create a default identity with generated key', function () {
                var cookieUser = JSON.parse(Cookies.get(idCookieName) || '');
                expect(cookieUser).toMatchObject(user);
                expect(manager.getUser()).toMatchObject(user);
            });
        });
        describe('when user undefined', function () {
            beforeEach(function () {
                manager = new SessionManager(envId);
            });
            it('should create a default identity with generated key', function () {
                var cookieUser = JSON.parse(Cookies.get(idCookieName) || '');
                expect(cookieUser).toMatchObject({
                    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
                    key: expect.any(String)
                });
                var user = manager.getUser();
                expect(user).toMatchObject({
                    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
                    key: expect.any(String)
                });
            });
        });
        describe('when user.key undefined', function () {
            beforeEach(function () {
                manager = new SessionManager(envId, { email: 'test@example.com' });
            });
            it('should create a default identity with generated key', function () {
                var cookieUser = JSON.parse(Cookies.get(idCookieName) || '');
                expect(cookieUser).toMatchObject({
                    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
                    key: expect.any(String),
                    email: 'test@example.com'
                });
                var user = manager.getUser();
                expect(user).toMatchObject({
                    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
                    key: expect.any(String),
                    email: 'test@example.com'
                });
            });
        });
    });
    //TODO: Test the session properties
    // describe('getIdentity', () => {
    //   beforeEach(() => {
    //     Cookies.set(idCookieName, JSON.stringify(sessionIdentity));
    //     manager = new SessionManager(envId);
    //   });
    //   it('should return it', () => {
    //     expect(manager.getSessionIdentity()).toEqual(sessionIdentity);
    //   });
    // });
    // describe('setIdentity', () => {
    //   const onChanged = jest.fn<EventDispatcher<SessionManager, SessionIdentity>, [unknown]>();
    //   beforeEach(() => {
    //     manager = new SessionManager(envId);
    //     manager.onChanged.subscribe(onChanged);
    //     manager.setSessionIdentity(sessionIdentity);
    //   });
    //   it('should set the identity', () => {
    //     const cookieIdentity = JSON.parse(Cookies.get(idCookieName) || '') as SessionIdentity;
    //     expect(cookieIdentity).toEqual(sessionIdentity);
    //   });
    //   it('should fire onChanged', () => {
    //     const expected: OnIdentityChangedEvent = {
    //       property: 'identity',
    //       value: defaultSessionIdentity
    //     };
    //     expect(onChanged).toBeCalledWith(expect.anything(), expected, expect.anything());
    //   });
    // });
    // describe('resetIdentity', () => {
    //   const onChanged = jest.fn<EventDispatcher<SessionManager, SessionIdentity>, [unknown]>();
    //   beforeEach(() => {
    //     manager = new SessionManager(envId);
    //     manager.onChanged.subscribe(onChanged);
    //     manager.resetSessionIdentity();
    //   });
    //   it('should reset the identity', () => {
    //     const cookieIdentity = JSON.parse(Cookies.get(idCookieName) || '') as SessionIdentity;
    //     expect(cookieIdentity).toEqual(defaultSessionIdentity);
    //   });
    //   it('should fire onChanged', () => {
    //     const expected: OnIdentityChangedEvent = {
    //       property: 'identity',
    //       value: defaultSessionIdentity
    //     };
    //     expect(onChanged).toBeCalledWith(expect.anything(), expected, expect.anything());
    //   });
    // });
});
//# sourceMappingURL=SessionManager.test.js.map