import { Context } from '.';
import { SessionManager } from '../../tracking/sessions/SessionManager';
import { contextMetadataFactory, sessionIdentityFactory, workflowContextEventsFactory } from '../__tests__/factories';
describe.only('Context', function () {
    var context;
    var sessionManager;
    var workflowMetadata;
    var workflowEvents;
    var identity;
    beforeEach(function () {
        workflowMetadata = contextMetadataFactory.build();
        workflowEvents = workflowContextEventsFactory.build();
        identity = sessionIdentityFactory.build();
        sessionManager = new SessionManager('envId');
        sessionManager.setSessionIdentity(identity);
        context = new Context(sessionManager, workflowMetadata, workflowEvents);
        // sessionManagerMock.getSessionIdentity.mockResolvedValue(identity);
    });
    describe('identity', function () {
        it('should contain the identity', function () {
            expect(context.identity).toEqual(identity);
        });
        describe('when session manager identity is updated', function () {
            beforeEach(function () {
                identity = sessionIdentityFactory.build({
                    userId: 'new-user-id'
                });
                sessionManager.setSessionIdentity(identity);
            });
            it('should update the identity', function () {
                expect(context.identity).toEqual(identity);
            });
        });
    });
    describe('events', function () {
        it('should contain the default event', function () {
            expect(context.events).toEqual(workflowEvents);
        });
    });
    describe('clone', function () {
        var newContext;
        describe('when new events is passed in', function () {
            beforeEach(function () {
                workflowEvents = workflowContextEventsFactory.build({
                    'new-test-step': {
                        'test-event': {
                            data: { test: 'test' }
                        }
                    }
                });
                newContext = context.clone(workflowEvents);
            });
            it('should clone the context and update the events', function () {
                expect(newContext.events).toEqual(workflowEvents);
                expect(newContext.identity).toEqual(context.identity);
                expect(newContext.metadata).toEqual(context.metadata);
            });
        });
        describe('when no events is not passed in', function () {
            beforeEach(function () {
                newContext = context.clone();
            });
            it('should clone the context with all default values', function () {
                expect(newContext.events).toEqual(context.events);
                expect(newContext.identity).toEqual(context.identity);
                expect(newContext.metadata).toEqual(context.metadata);
            });
        });
    });
});
//# sourceMappingURL=Context.test.js.map