import { buildStepConfigTree } from './buildStepConfigTree';
describe('buildStepConfigTree()', function () {
    /*
      The following threeLayerCase should look like the following diagram:
            ┌──────┐
            │ root │
            └──┬───┘
                │
            ┌───┴───┐
      ┌─────┤       ├────┐
      │  a  │       │ b  │
      └──┬──┘       └────┘
        │
      ┌──┴──┐
      │  a1 │
      └─────┘
   */
    var rootStepConfig = {
        name: 'root',
        uses: ''
    };
    var aStepConfig = {
        name: 'a',
        uses: '',
        needs: {
            name: 'root'
        }
    };
    var a1StepConfig = {
        name: 'a1',
        uses: '',
        needs: {
            name: 'a'
        }
    };
    var bStepConfig = {
        name: 'b',
        uses: '',
        needs: {
            name: 'root'
        }
    };
    // expected tree nodes
    var rootNode = {
        config: rootStepConfig,
        stepInstances: []
    };
    var aNode = {
        config: aStepConfig,
        stepInstances: [],
        parent: rootNode
    };
    var a1Node = {
        config: a1StepConfig,
        stepInstances: [],
        parent: aNode
    };
    var bNode = {
        config: bStepConfig,
        stepInstances: [],
        parent: rootNode
    };
    var threeLayerCase = {
        name: 'when config tree is valid with multiple layers and branches',
        stepConfigs: [rootStepConfig, aStepConfig, a1StepConfig, bStepConfig],
        expectedConfigNodes: new Map([
            ['root', rootNode],
            ['a', aNode],
            ['a1', a1Node],
            ['b', bNode]
        ])
    };
    var singleRootNodeCase = {
        name: 'when config tree is valid with single root node',
        stepConfigs: [rootStepConfig],
        expectedConfigNodes: new Map([['root', rootNode]])
    };
    describe.each([threeLayerCase, singleRootNodeCase])('$name', function (_a) {
        var stepConfigs = _a.stepConfigs, expectedConfigNodes = _a.expectedConfigNodes;
        it('should build a tree from the given step configs', function () {
            var actualConfigNodes = buildStepConfigTree(stepConfigs);
            expect(actualConfigNodes).toEqual(expectedConfigNodes);
        });
    });
});
//# sourceMappingURL=buildStepConfigTree.test.js.map