import { getDependencyConfigKeys } from './getDependencyConfigKeys';
/*
    three layer case
           ┌──────┐
           │ root │
           └──┬───┘
              │
        ┌─────┴─────┐
        │           │
      eventA      eventB
        │           │
      ┌─┴─┐       ┌─┴─┐
      │ A │       │ B │
      └─┬─┘       └───┘
        │
  ┌─────┴────┐
  │          │
eventA    eventA
  │          │
┌─┴──┐     ┌─┴──┐
│ A1 │     │ A2 │
└────┘     └────┘
 */
var rootStepConfig = {
    name: 'root',
    uses: ''
};
var aStepConfig = {
    name: 'a',
    uses: '',
    needs: {
        name: 'root',
        event: 'eventA'
    }
};
var a1StepConfig = {
    name: 'a1',
    uses: '',
    needs: {
        name: 'a',
        event: 'eventA'
    }
};
var a2StepConfig = {
    name: 'a1',
    uses: '',
    needs: {
        name: 'a',
        event: 'eventA'
    }
};
var bStepConfig = {
    name: 'b',
    uses: '',
    needs: {
        name: 'root',
        event: 'eventB'
    }
};
// expected tree nodes
var rootNode = {
    config: rootStepConfig,
    stepInstances: []
};
var aNode = {
    config: aStepConfig,
    stepInstances: [],
    parent: rootNode
};
var a1Node = {
    config: a1StepConfig,
    stepInstances: [],
    parent: aNode
};
var a2Node = {
    config: a2StepConfig,
    stepInstances: [],
    parent: aNode
};
var bNode = {
    config: bStepConfig,
    stepInstances: [],
    parent: rootNode
};
describe('getDependencyConfigKeys()', function () {
    var manyDepdendencies = {
        name: 'when step event has many dependencies in the config tree',
        map: new Map([
            ['root', rootNode],
            ['a', aNode],
            ['a1', a1Node],
            ['a2', a2Node],
            ['b', bNode]
        ]),
        stepEvent: {
            stepName: 'a',
            event: 'eventA',
            data: {}
        },
        expected: ['a1', 'a2']
    };
    var singleDependency = {
        name: 'when step event has a single dependency in the config tree',
        map: new Map([
            ['root', rootNode],
            ['a', aNode],
            ['a1', a1Node],
            ['a2', a2Node],
            ['b', bNode]
        ]),
        stepEvent: {
            stepName: 'root',
            event: 'eventA',
            data: {}
        },
        expected: ['a']
    };
    var noDependency = {
        name: 'when step event has no dependencies in the config tree',
        map: new Map([
            ['root', rootNode],
            ['a', aNode],
            ['a1', a1Node],
            ['a2', a2Node],
            ['b', bNode]
        ]),
        stepEvent: {
            stepName: 'b',
            event: 'eventB',
            data: {}
        },
        expected: []
    };
    describe.each([manyDepdendencies, singleDependency, noDependency])('success: $name', function (_a) {
        var map = _a.map, stepEvent = _a.stepEvent, expected = _a.expected;
        it("should get all the right keys for the dependencies", function () {
            var actual = getDependencyConfigKeys(map, stepEvent);
            expect(actual).toEqual(expected);
        });
    });
});
//# sourceMappingURL=getDependencyConfigKeys.test.js.map