import { getRootConfigKey } from './getRootConfigKey';
/*
    The following threeLayerCase should look like the following diagram:
          ┌──────┐
          │ root │
          └──┬───┘
              │
          ┌───┴───┐
    ┌─────┤       ├────┐
    │  a  │       │ b  │
    └──┬──┘       └────┘
      │
    ┌──┴──┐
    │  a1 │
    └─────┘
 */
var rootStepConfig = {
    name: 'root',
    uses: ''
};
var aStepConfig = {
    name: 'a',
    uses: '',
    needs: {
        name: 'root'
    }
};
var a1StepConfig = {
    name: 'a1',
    uses: '',
    needs: {
        name: 'a'
    }
};
var bStepConfig = {
    name: 'b',
    uses: '',
    needs: {
        name: 'root'
    }
};
// expected tree nodes
var rootNode = {
    config: rootStepConfig,
    stepInstances: []
};
var aNode = {
    config: aStepConfig,
    stepInstances: [],
    parent: rootNode
};
var a1Node = {
    config: a1StepConfig,
    stepInstances: [],
    parent: aNode
};
var bNode = {
    config: bStepConfig,
    stepInstances: [],
    parent: rootNode
};
describe('getRootConfigKey()', function () {
    var threeLayerCase = {
        name: 'when config tree is valid with multiple layers and branches',
        map: new Map([
            ['root', rootNode],
            ['a', aNode],
            ['a1', a1Node],
            ['b', bNode]
        ]),
        expected: 'root'
    };
    describe.each([threeLayerCase])('success: $name', function (_a) {
        var map = _a.map, expected = _a.expected;
        it("should return correctly", function () {
            var actual = getRootConfigKey(map);
            expect(actual).toEqual(expected);
        });
    });
    var noRootCase = {
        name: 'when config tree has no root node',
        map: new Map([
            ['a', aNode],
            ['a1', a1Node],
            ['b', bNode]
        ]),
        expectedError: 'Could not find root config'
    };
    describe.each([noRootCase])('$name', function (_a) {
        var map = _a.map, expectedError = _a.expectedError;
        it("should throw correct error", function () {
            expect(function () { return getRootConfigKey(map); }).toThrowError(expectedError);
        });
    });
});
//# sourceMappingURL=getRootConfigKey.test.js.map