import { screen } from '@testing-library/dom';
import userEvent from '@testing-library/user-event';
import { contextFactory } from '../../../__tests__/factories';
import { ElementEventStrategy } from './ElementEventStrategy';
describe('ElementEvent', function () {
    var cssClass = 'some-selector';
    var elementEventStrategy;
    var onTriggerEventMock = jest.fn();
    beforeEach(function () {
        document.body.innerHTML = "";
    });
    describe('css selector exists', function () {
        var context = contextFactory.build();
        beforeEach(function () {
            document.body.innerHTML = "\n      <button class='".concat(cssClass, "'>some button</button>\n      ");
        });
        describe('click event', function () {
            var props = {
                cssSelector: ".".concat(cssClass),
                event: 'ElementClick'
            };
            beforeEach(function () {
                elementEventStrategy = new ElementEventStrategy(context, props);
                elementEventStrategy.start();
                elementEventStrategy.onEventTriggered = onTriggerEventMock;
            });
            it('should fire the onEventTriggered event', function () {
                userEvent.click(screen.getByRole('button'));
                expect(onTriggerEventMock).toBeCalledWith(expect.objectContaining({
                    condition: true
                }));
            });
        });
        describe('mouseover event', function () {
            var props = {
                cssSelector: ".".concat(cssClass),
                event: 'ElementMouseOver'
            };
            beforeEach(function () {
                elementEventStrategy = new ElementEventStrategy(context, props);
                elementEventStrategy.start();
                elementEventStrategy.onEventTriggered = onTriggerEventMock;
            });
            it('should fire the onEventTriggered event', function () {
                userEvent.hover(screen.getByRole('button'));
                expect(onTriggerEventMock).toBeCalledWith(expect.objectContaining({
                    condition: true,
                    props: props
                }));
            });
        });
    });
    describe('when css selector exist on element with default behavior', function () {
        var context = contextFactory.build();
        beforeEach(function () {
            document.body.innerHTML = "\n      <a href='https://google.com' class='".concat(cssClass, "'>some button</a>\n      ");
        });
        describe('when event is fired when delayDefaultBehavior is true', function () {
            var props = {
                cssSelector: ".".concat(cssClass),
                event: 'ElementClick',
                delayDefaultBehavior: true
            };
            beforeEach(function () {
                elementEventStrategy = new ElementEventStrategy(context, props);
                elementEventStrategy.start();
                elementEventStrategy.onEventTriggered = onTriggerEventMock;
            });
            it('should fire the onEventTriggered event', function () {
                userEvent.click(screen.getByRole('link'));
                expect(onTriggerEventMock).toBeCalledWith(expect.objectContaining({
                    condition: true
                }));
            });
            // it('should disable the default behavior', () => {});
            // describe('when workflow is completed', () => {
            //   beforeEach(() => {
            //     context.Completed('completed');
            //   });
            //   it('should resume the default behavior', () => {});
            // });
        });
    });
});
//# sourceMappingURL=ElementEventStrategy.test.js.map