var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { PageEventStrategy } from './PageEventStrategy';
import { mock } from 'jest-mock-extended';
import { contextFactory } from '../../../__tests__/factories';
describe('PageEventStrategy', function () {
    var pageEventStrategy;
    var mockObserver;
    var onTriggerEventMock;
    beforeEach(function () {
        onTriggerEventMock = jest.fn();
        mockObserver = jest
            .fn()
            .mockImplementation(function () { return mock(); });
        // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
        global.MutationObserver = mockObserver;
    });
    function fireMutationObserver() {
        var instance = mockObserver.mock.instances[0];
        var cb = mockObserver.mock.calls[0][0];
        cb([], instance);
    }
    function getInstance(props) {
        var context = contextFactory.build();
        var instance = new PageEventStrategy(context, props);
        instance.onEventTriggered = onTriggerEventMock;
        return instance;
    }
    function setUrl(url) {
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        delete window.location;
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        window.location = new URL(url);
    }
    // JSDOM does not allow us to modify location, see https://stackoverflow.com/a/60110508/400861
    var realLocation = window.location;
    afterEach(function () {
        window.location = realLocation;
    });
    var defaultUrl = 'https://samelogic.com/valid/url';
    var defaultProps = {
        event: 'PageView',
        urlPattern: defaultUrl
    };
    describe.each([
        {
            name: 'when url matches on start',
            urls: [defaultUrl],
            props: defaultProps,
            expectedTriggerCount: 1
        },
        {
            name: 'when url matches regex on start with query param',
            urls: [defaultUrl, 'https://samelogic.com/?gtm_debug=x'],
            props: __assign(__assign({}, defaultProps), { urlPattern: 'https://samelogic.com/*' }),
            expectedTriggerCount: 2
        },
        {
            name: 'when url matches regex on start',
            urls: [defaultUrl],
            props: __assign(__assign({}, defaultProps), { urlPattern: 'https://samelogic.com/*/url' }),
            expectedTriggerCount: 1
        },
        {
            name: 'when url does not match on start',
            urls: [defaultUrl],
            props: __assign(__assign({}, defaultProps), { urlPattern: 'https://samelogic.com/*/wrong-url' }),
            expectedTriggerCount: 0
        },
        {
            name: 'when url matches after started',
            urls: [defaultUrl, 'https://samelogic.com/new-url/url'],
            props: __assign(__assign({}, defaultProps), { urlPattern: 'https://samelogic.com/new-url/url' }),
            expectedTriggerCount: 1
        },
        {
            name: 'when url matches regex after started',
            urls: [defaultUrl, 'https://samelogic.com/url/new-url'],
            props: __assign(__assign({}, defaultProps), { urlPattern: 'https://samelogic.com/*/new-url' }),
            expectedTriggerCount: 1
        },
        {
            name: 'when url does not match after started',
            urls: [defaultUrl, 'https://samelogic.com/new-url/url'],
            props: __assign(__assign({}, defaultProps), { urlPattern: 'https://samelogic.com/invalid/url' }),
            expectedTriggerCount: 0
        }
    ])('$name', function (_a) {
        var urls = _a.urls, props = _a.props, expectedTriggerCount = _a.expectedTriggerCount;
        beforeEach(function () {
            pageEventStrategy = getInstance(props);
            pageEventStrategy.start();
            for (var _i = 0, urls_1 = urls; _i < urls_1.length; _i++) {
                var url = urls_1[_i];
                setUrl(url);
                fireMutationObserver();
                // Aded a second fire to ensure we trigger the event only when the
                // url has changed. Since we are using MutationObserver, this will
                // fire multiple times without the URL changing.
                fireMutationObserver();
            }
        });
        it("should ".concat(expectedTriggerCount > 0 ? '' : 'not ', "execute the trigger"), function () {
            expect(onTriggerEventMock).toHaveBeenCalledTimes(expectedTriggerCount);
            if (expectedTriggerCount > 0) {
                expect(onTriggerEventMock).toBeCalledWith(expect.objectContaining({
                    condition: true,
                    props: props,
                    data: { href: urls[urls.length - 1] }
                }));
            }
        });
    });
});
//# sourceMappingURL=PageEventStrategy.test.js.map