jest.mock('../TriggerEvent');
import { mock } from 'jest-mock-extended';
import { contextFactory } from '../../__tests__/factories';
import { TriggerEvent } from '../TriggerEvent';
import { TriggerManager } from './TriggerManager';
var mockedTriggerEvent = TriggerEvent;
beforeEach(function () {
    mockedTriggerEvent.mockClear();
});
describe('TriggerManager', function () {
    describe.each([
        {
            name: 'when one event is triggered',
            triggerConfigs: [
                {
                    event: 'PageView',
                    urlPattern: '/*'
                }
            ],
            onTriggerEvents: [
                {
                    condition: true,
                    props: {
                        event: 'PageView',
                        urlPattern: ''
                    },
                    data: {}
                }
            ],
            expectedTriggerCount: 1
        },
        {
            name: 'when no event is triggered',
            triggerConfigs: [
                {
                    event: 'PageView',
                    urlPattern: '/*'
                }
            ],
            onTriggerEvents: [],
            expectedTriggerCount: 0
        },
        {
            name: 'when one of many events are triggered',
            triggerConfigs: [
                {
                    event: 'PageView',
                    urlPattern: '/*'
                },
                {
                    event: 'ElementClick',
                    cssSelector: '.test'
                }
            ],
            onTriggerEvents: [
                {
                    condition: true,
                    props: {
                        event: 'PageView',
                        urlPattern: ''
                    },
                    data: {}
                }
            ],
            expectedTriggerCount: 0
        },
        {
            name: 'when all of many events are triggered',
            triggerConfigs: [
                {
                    id: '1',
                    event: 'PageView',
                    urlPattern: '/*'
                },
                {
                    id: '2',
                    event: 'ElementClick',
                    cssSelector: '.test'
                }
            ],
            onTriggerEvents: [
                {
                    condition: true,
                    props: {
                        event: 'PageView',
                        urlPattern: ''
                    },
                    data: {}
                },
                {
                    condition: true,
                    props: {
                        event: 'ElementClick',
                        cssSelector: '.test'
                    },
                    data: {}
                }
            ],
            expectedTriggerCount: 1
        },
        {
            name: 'when no trigger is configured',
            onTriggerEvents: [],
            expectedTriggerCount: 1
        },
        {
            name: 'when no trigger events exists',
            triggerConfigs: [],
            onTriggerEvents: [],
            expectedTriggerCount: 1
        }
    ])('$name', function (_a) {
        var triggerConfigs = _a.triggerConfigs, onTriggerEvents = _a.onTriggerEvents, expectedTriggerCount = _a.expectedTriggerCount;
        var triggerContainer;
        var onTriggerMock;
        var loggerMock;
        var workflowContext = contextFactory.build();
        var mockTriggerEvents;
        beforeEach(function () {
            var _a;
            loggerMock = mock();
            onTriggerMock = jest.fn();
            mockTriggerEvents = [];
            var _loop_1 = function (eventData) {
                var mockEvent = mock();
                mockedTriggerEvent.mockImplementationOnce(function () {
                    return mockEvent;
                });
                mockTriggerEvents.push({
                    mockEvent: mockEvent,
                    eventData: eventData
                });
            };
            for (var _i = 0, onTriggerEvents_1 = onTriggerEvents; _i < onTriggerEvents_1.length; _i++) {
                var eventData = onTriggerEvents_1[_i];
                _loop_1(eventData);
            }
            triggerContainer = new TriggerManager(workflowContext, loggerMock, triggerConfigs);
            triggerContainer.onTriggered = onTriggerMock;
            triggerContainer.start();
            for (var _b = 0, mockTriggerEvents_1 = mockTriggerEvents; _b < mockTriggerEvents_1.length; _b++) {
                var _c = mockTriggerEvents_1[_b], mockEvent = _c.mockEvent, eventData = _c.eventData;
                if (eventData) {
                    (_a = mockEvent.onChanged) === null || _a === void 0 ? void 0 : _a.call(mockEvent, eventData);
                }
            }
        });
        it('should start the event triggers', function () {
            for (var _i = 0, mockTriggerEvents_2 = mockTriggerEvents; _i < mockTriggerEvents_2.length; _i++) {
                var mockEvent = mockTriggerEvents_2[_i].mockEvent;
                expect(mockEvent.start).toHaveBeenCalled();
            }
        });
        it("should ".concat(expectedTriggerCount > 0 ? '' : 'not ', "execute the trigger"), function () {
            expect(onTriggerMock).toHaveBeenCalledTimes(expectedTriggerCount);
        });
    });
});
//# sourceMappingURL=TriggerManager.test.js.map