import { Options } from './models';
/**
 * Samelogic Client SDK API. The Samelogic class handles the creation of a client instance.
 *
 * @public
 */
export declare class Samelogic {
    private readonly options;
    private readonly config;
    private readonly logger;
    private readonly sessionManager;
    private readonly projectsRepository;
    private readonly remotePackageRepository;
    private readonly packageMemoryCache;
    /**
     * The current version of the library
     */
    readonly version: string;
    private workflowManagers;
    /**
     * Samelogic Client SDK API - instance constructor. The Samelogic class handles the creation and configuration
     * of a client instance.
     *
     * @param options - the configuration options for the client instance.
     *
     * @public
     */
    constructor(options: Options);
    /**
     * Initializes the client instance. This will start the client to begin listening for triggers and executing worklows.
     *
     * @public
     */
    init(): Promise<void>;
    private initSession;
    private hotLoadPackages;
    /**
     * Creates an instance of the client and then initializes it. This is a static method and is a convenience method
     * for initializing through a single API call from the window object. This allows tools like Google Tag Manager
     * to initialize the client instance without the `new` keyword being available.
     *
     * @public
     */
    static init(options: Options): Promise<Samelogic>;
    /**
     * This method is used to uniquelly identify the user for maintaining an association across sessions.
     *
     * @param identity - this is a unique identifier for the user, such as an email address or a user ID.
     * @param properties - this is a set of key/value pairs that can be used to enrich the user's profile.
     */
    identify(identity: string, properties?: Record<string, string>): void;
    /**
     * This method is used to reset the user session and identity. This can be used when the user logs out.
     */
    resetIdentity(): void;
}
//# sourceMappingURL=Samelogic.d.ts.map