"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SessionManager = void 0;
var ulid_1 = require("ulid");
var ste_events_1 = require("ste-events");
var js_cookie_1 = __importDefault(require("js-cookie"));
var PROPS_COOKIE_PREFIX = '_sl_props';
var ID_COOKIE_PREFIX = '_sl_id';
var SessionManager = /** @class */ (function () {
    function SessionManager(envId, user) {
        this.envId = envId;
        // We need to use SameSite=None for iframe support
        this.cookieApi = js_cookie_1.default.withAttributes({ sameSite: 'None', secure: true });
        this._onChanged = new ste_events_1.EventDispatcher();
        this.setUser(user);
        this.setSessionProperties({
            envId: this.envId,
            projId: '',
            orgId: ''
        });
    }
    SessionManager.prototype.setSessionProperties = function (sessionProperties) {
        this.cookieApi.set("".concat(PROPS_COOKIE_PREFIX, ".").concat(this.envId), JSON.stringify(sessionProperties));
        this._onChanged.dispatch(this, {
            property: 'properties',
            value: sessionProperties
        });
    };
    SessionManager.prototype.setSessionIdentity = function (sessionIdentity) {
        this.cookieApi.set("".concat(ID_COOKIE_PREFIX, ".").concat(this.envId), JSON.stringify(sessionIdentity));
        this._onChanged.dispatch(this, {
            property: 'identity',
            value: sessionIdentity
        });
    };
    SessionManager.prototype.setUser = function (user) {
        if (user === void 0) { user = { key: (0, ulid_1.ulid)() }; }
        if (user.key === undefined) {
            user.key = (0, ulid_1.ulid)();
        }
        this.cookieApi.set("".concat(ID_COOKIE_PREFIX, ".").concat(this.envId), JSON.stringify(user));
    };
    SessionManager.prototype.getUser = function () {
        var cookieUserString = this.cookieApi.get("".concat(ID_COOKIE_PREFIX, ".").concat(this.envId));
        return cookieUserString ? JSON.parse(cookieUserString) : null;
    };
    SessionManager.prototype.getBase64User = function () {
        var cookieUserString = this.cookieApi.get("".concat(ID_COOKIE_PREFIX, ".").concat(this.envId));
        return cookieUserString ? btoa(cookieUserString) : '';
    };
    /**
     * Get the session identity from the cookie. If it does not exist, one will be created.
     */
    SessionManager.prototype.getSessionIdentity = function () {
        var identity = this.getIdentity();
        if (identity === null) {
            throw new Error('Session identity not found');
        }
        return identity;
    };
    SessionManager.prototype.getIdentity = function () {
        var sessionIdentityString = this.cookieApi.get("".concat(ID_COOKIE_PREFIX, ".").concat(this.envId));
        return sessionIdentityString ? JSON.parse(sessionIdentityString) : null;
    };
    SessionManager.prototype.resetSessionIdentity = function () {
        this.setSessionIdentity({
            sessionId: (0, ulid_1.ulid)(),
            userId: (0, ulid_1.ulid)()
        });
    };
    Object.defineProperty(SessionManager.prototype, "onChanged", {
        get: function () {
            return this._onChanged.asEvent();
        },
        enumerable: false,
        configurable: true
    });
    return SessionManager;
}());
exports.SessionManager = SessionManager;
//# sourceMappingURL=SessionManager.js.map