import { Logger, StepEvent, StepPackage, WorkflowContext } from '@samelogic/steps';
import { StepConfig } from '../../../models';
/**
 * StepContainers are used to isolate the step package from the rest of the application.
 * A Step has a few events:
 * - initialize (constructor) - this will setup the infrastructure (logger, broker, config, package)
 * - run - can be called multiple times with new properties
 * - dispose - used to dispose/stop the step.
 */
export declare class StepContainer {
    private readonly context;
    private readonly packageInstance;
    /**
     * This handler is triggered
     */
    onEventTriggered?: (event: StepEvent) => Promise<void>;
    /**
     * This is the props created from the interpolation of the config and the context
     */
    private readonly inputProps;
    readonly instanceId: string;
    constructor(context: WorkflowContext, stepPackage: StepPackage, config: StepConfig, logger: Logger);
    run(): Promise<void>;
    private handlePackageEventTriggered;
    dispose(): Promise<void>;
}
//# sourceMappingURL=StepContainer.d.ts.map