"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var jest_mock_extended_1 = require("jest-mock-extended");
var StepContainer_1 = require("./StepContainer");
var MockPackage_1 = require("../../__tests__/MockPackage");
var factories_1 = require("../../__tests__/factories");
beforeEach(function () {
    jest.resetModules();
    jest.resetAllMocks();
});
describe('StepContainer', function () {
    var stepContainer;
    // dependencies
    var context = factories_1.contextFactory.build();
    var config = {
        name: 'step-config',
        uses: 'https://step-url',
        needs: {
            name: 'some-name'
        }
    };
    var inputProps = {
        title: 'Props Schema',
        type: 'object',
        properties: {
            prop1: {
                type: 'string'
            },
            prop2: {
                type: 'string'
            },
            intProp: {
                type: 'integer'
            },
            boolProp: {
                type: 'boolean'
            }
        },
        additionalProperties: false,
        required: ['prop1', 'intProp', 'boolProp']
    };
    var mockLogger;
    var mockNewableModule;
    var mockModule;
    beforeEach(function () {
        mockLogger = (0, jest_mock_extended_1.mock)();
        mockModule = (0, jest_mock_extended_1.mock)();
        mockNewableModule = jest.fn().mockImplementation(function () { return mockModule; });
    });
    var noTemplateCase = {
        name: 'when config is valid and does not contain string templates',
        context: factories_1.contextFactory.build(),
        schema: {
            events: {},
            props: inputProps
        },
        config: {
            name: 'step-config',
            uses: 'https://step-url',
            props: {
                prop1: 'prop1-value',
                prop2: 'prop2-value',
                intProp: 1,
                boolProp: true
            }
        },
        expectedPackageRunProps: {
            prop1: 'prop1-value',
            prop2: 'prop2-value',
            intProp: 1,
            boolProp: true
        }
    };
    var templateCase = {
        name: 'when config is valid and contains templated properties',
        context: factories_1.contextFactory.build({
            metadata: { name: 'workflow-context' },
            events: {
                'step-name': {
                    'hello-event-name': { data: { hello: 'hello' } },
                    'world-event-name': { data: { world: 'world!' } }
                },
                'step1-name': {
                    'event1-name': { data: { boolProp: false, numProp2Map: 2 } }
                }
            }
        }),
        schema: {
            events: {},
            props: inputProps
        },
        config: {
            name: 'step-config',
            uses: 'https://step-url',
            props: {
                prop1: '{{ events.step-name.hello-event-name.data.hello }} {{ events.step-name.world-event-name.data.world }}',
                prop2: '{{ events.step-name.hello-event-name.data.hello }}',
                intProp: 1,
                boolProp: '{{ events.step1-name.event1-name.data.boolProp }}'
            }
        },
        expectedPackageRunProps: {
            prop1: 'hello world!',
            prop2: 'hello',
            intProp: 1,
            boolProp: false
        }
    };
    describe.each([noTemplateCase, templateCase])('run(): $name', function (_a) {
        var context = _a.context, schema = _a.schema, config = _a.config, expectedPackageRunProps = _a.expectedPackageRunProps;
        it('should run the step', function () { return __awaiter(void 0, void 0, void 0, function () {
            var stepPackage, stepContainer;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        stepPackage = {
                            module: mockNewableModule,
                            schema: schema
                        };
                        stepContainer = new StepContainer_1.StepContainer(context, stepPackage, config, mockLogger);
                        expect(stepContainer.instanceId).not.toBeUndefined();
                        return [4 /*yield*/, stepContainer.run()];
                    case 1:
                        _a.sent();
                        expect(mockModule.run).toHaveBeenCalledWith(context, expectedPackageRunProps);
                        return [2 /*return*/];
                }
            });
        }); });
    });
    describe.each([
        {
            name: 'when multiple separate events are fired',
            events: [
                { stepName: 'test', event: '1', data: { key: 'value-1' } },
                { stepName: 'test', event: '2', data: { key: 'value-2' } }
            ],
            expectedEvents: [
                { stepName: 'test', event: '1', data: { key: 'value-1' } },
                { stepName: 'test', event: '2', data: { key: 'value-2' } }
            ]
        }
    ])('$name', function (_a) {
        var events = _a.events, expectedEvents = _a.expectedEvents;
        var onTriggerEventMock = jest.fn();
        beforeEach(function () {
            var _a;
            var stepPackage = {
                module: mockNewableModule,
                schema: MockPackage_1.schema
            };
            stepContainer = new StepContainer_1.StepContainer(context, stepPackage, config, mockLogger);
            stepContainer.onEventTriggered = onTriggerEventMock;
            for (var _i = 0, events_1 = events; _i < events_1.length; _i++) {
                var event_1 = events_1[_i];
                (_a = mockModule.onEventTriggered) === null || _a === void 0 ? void 0 : _a.call(mockModule, event_1);
            }
        });
        it('should fire the event correctly', function () {
            for (var i = 0; i < expectedEvents.length; i++) {
                // eslint-disable-next-line security/detect-object-injection
                var expected = expectedEvents[i];
                expect(onTriggerEventMock).toHaveBeenNthCalledWith(i + 1, expected);
            }
        });
    });
    describe('dispose', function () {
        beforeEach(function () { return __awaiter(void 0, void 0, void 0, function () {
            var stepPackage;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        stepPackage = {
                            module: mockNewableModule,
                            schema: MockPackage_1.schema
                        };
                        stepContainer = new StepContainer_1.StepContainer(context, stepPackage, config, mockLogger);
                        return [4 /*yield*/, stepContainer.dispose()];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
        it('should dispose of the step package', function () {
            expect(mockModule.dispose).toBeCalled();
        });
    });
});
//# sourceMappingURL=StepContainer.test.js.map