"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
jest.mock('../StepContainer');
var StepContainerManager_1 = require("./StepContainerManager");
var StepContainer_1 = require("../StepContainer");
var jest_mock_extended_1 = require("jest-mock-extended");
var MockPackage_1 = require("../../__tests__/MockPackage");
var factories_1 = require("../../__tests__/factories");
var Context_1 = require("../../Context/Context");
var tracking_1 = require("../../../tracking");
var mockedStepContainer = StepContainer_1.StepContainer;
beforeEach(function () {
    mockedStepContainer.mockClear();
});
describe('StepContainerManager', function () {
    // type CaseEvent = {
    //   /**
    //    * The id of the step node instance that fired the event
    //    */
    //   instanceId: string;
    //   event: string;
    /*
      three layer case
             ┌──────┐
             │ root │
             └──┬───┘
                │
          ┌─────┴─────┐
          │           │
        eventA      eventB
          │           │
        ┌─┴─┐       ┌─┴─┐
        │ A │       │ B │
        └─┬─┘       └───┘
          │
    ┌─────┴────┐
    │          │
  eventA    eventA
    │          │
  ┌─┴──┐     ┌─┴──┐
  │ A1 │     │ A2 │
  └────┘     └────┘
   */
    var context = new Context_1.Context(new tracking_1.SessionManager('env-id'), factories_1.contextMetadataFactory.build(), {});
    var threeLayerSuccessCase = {
        name: 'when workflow is executed with all matching schemas',
        configs: new Map([
            [
                'root',
                {
                    config: {
                        name: 'root',
                        uses: ''
                    },
                    package: MockPackage_1.stepPackage,
                    expectedContext: context,
                    firedEvents: [
                        {
                            stepName: 'root',
                            event: 'eventA',
                            data: {
                                test: 'test-1'
                            }
                        },
                        {
                            stepName: 'root',
                            event: 'eventB',
                            data: {
                                num: 1
                            }
                        }
                    ]
                }
            ],
            [
                'a',
                {
                    config: {
                        name: 'a',
                        uses: '',
                        needs: {
                            name: 'root',
                            event: 'eventA'
                        },
                        props: {
                            'hard-coded-prop': 'hard-coded',
                            'mapped-prop': '${events.root.eventA.data.test}'
                        }
                    },
                    package: MockPackage_1.stepPackage,
                    expectedContext: context.clone({ root: { eventA: { data: { test: 'test-1' } } } }),
                    firedEvents: [
                        {
                            stepName: 'a',
                            event: 'eventA',
                            data: {
                                a: 'a1'
                            }
                        },
                        {
                            stepName: 'a',
                            event: 'eventA',
                            data: {
                                a: 'a2'
                            }
                        }
                    ]
                }
            ],
            [
                'a1',
                {
                    config: {
                        name: 'a1',
                        uses: '',
                        needs: {
                            name: 'a',
                            event: 'eventA'
                        }
                    },
                    package: MockPackage_1.stepPackage,
                    expectedRunProps: null,
                    expectedContext: context.clone({
                        root: { eventA: { data: { test: 'test-1' } } },
                        a: { eventA: { data: { a: 'a1' } } }
                    }),
                    firedEvents: []
                }
            ],
            [
                'a2',
                {
                    config: {
                        name: 'a1',
                        uses: '',
                        needs: {
                            name: 'a',
                            event: 'eventA'
                        }
                    },
                    package: MockPackage_1.stepPackage,
                    expectedContext: factories_1.contextFactory.build({
                        events: { root: { eventA: { data: { test: 'test-1' } } }, a: { eventA: { data: { a: 'a2' } } } }
                    }),
                    firedEvents: []
                }
            ],
            [
                'b',
                {
                    config: {
                        name: 'b',
                        uses: '',
                        needs: {
                            name: 'root',
                            event: 'eventB'
                        }
                    },
                    package: MockPackage_1.stepPackage,
                    expectedContext: factories_1.contextFactory.build({
                        events: { root: { eventB: { data: { num: 1 } } } }
                    }),
                    firedEvents: []
                }
            ]
        ])
    };
    describe.each([threeLayerSuccessCase])('$name', function (_a) {
        var configs = _a.configs;
        var loggerMock;
        var packageCacheMock;
        var eventLoggerMock;
        beforeEach(function () {
            loggerMock = (0, jest_mock_extended_1.mock)();
            packageCacheMock = (0, jest_mock_extended_1.mock)();
            eventLoggerMock = (0, jest_mock_extended_1.mock)();
        });
        it('should execute all steps with the right props', function () { return __awaiter(void 0, void 0, void 0, function () {
            var allConfigs, mockContainers, _i, allConfigs_1, config, _tmpContexts, manager, checkStepRan, triggerEventForStep;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        allConfigs = Array.from(configs, function (_a) {
                            var _key = _a[0], value = _a[1];
                            return value.config;
                        });
                        mockContainers = new Map();
                        for (_i = 0, allConfigs_1 = allConfigs; _i < allConfigs_1.length; _i++) {
                            config = allConfigs_1[_i];
                            mockContainers.set(config.name, (0, jest_mock_extended_1.mock)());
                        }
                        _tmpContexts = new Array();
                        mockedStepContainer.mockImplementation(function (_ctx, _pkg, cfg) {
                            _tmpContexts.push(_ctx);
                            var container = mockContainers.get(cfg.name);
                            if (container == null) {
                                throw Error('cannot find mock container');
                            }
                            return container;
                        });
                        packageCacheMock.get.mockResolvedValue(MockPackage_1.stepPackage);
                        manager = new StepContainerManager_1.StepContainerManager(allConfigs, packageCacheMock, loggerMock, eventLoggerMock);
                        checkStepRan = function (stepName) {
                            var runningconfig = configs.get(stepName);
                            if (runningconfig === undefined) {
                                throw new Error("Cannot find step: ".concat(stepName));
                            }
                            expect(mockedStepContainer).toHaveBeenCalledWith(runningconfig.expectedContext, expect.any(Object), runningconfig.config, loggerMock);
                            var mockContainer = mockContainers.get(runningconfig.config.name);
                            if (mockContainer == null) {
                                throw Error('cannot find mock container');
                            }
                            expect(mockContainer.run).toHaveBeenCalled();
                        };
                        triggerEventForStep = function (stepName) { return __awaiter(void 0, void 0, void 0, function () {
                            var runningconfig, mockContainer, _i, _a, event_1;
                            var _b;
                            return __generator(this, function (_c) {
                                switch (_c.label) {
                                    case 0:
                                        runningconfig = configs.get(stepName);
                                        if (runningconfig === undefined) {
                                            throw new Error("Cannot find step ".concat(stepName));
                                        }
                                        mockContainer = mockContainers.get(runningconfig.config.name);
                                        if (mockContainer == null) {
                                            throw Error('cannot find mock container');
                                        }
                                        _i = 0, _a = runningconfig.firedEvents;
                                        _c.label = 1;
                                    case 1:
                                        if (!(_i < _a.length)) return [3 /*break*/, 4];
                                        event_1 = _a[_i];
                                        return [4 /*yield*/, ((_b = mockContainer.onEventTriggered) === null || _b === void 0 ? void 0 : _b.call(mockContainer, event_1))];
                                    case 2:
                                        _c.sent();
                                        _c.label = 3;
                                    case 3:
                                        _i++;
                                        return [3 /*break*/, 1];
                                    case 4: return [2 /*return*/];
                                }
                            });
                        }); };
                        return [4 /*yield*/, manager.start(context)];
                    case 1:
                        _a.sent();
                        // check first step
                        checkStepRan('root');
                        return [4 /*yield*/, triggerEventForStep('root')];
                    case 2:
                        _a.sent();
                        checkStepRan('a');
                        return [2 /*return*/];
                }
            });
        }); });
    });
});
//# sourceMappingURL=StepContainerManager.test.js.map