import { TriggerEventProps } from '../../../../models';
import { EventStrategy } from './EventStrategy';
import { WorkflowContext } from '@samelogic/steps';
export declare type ElementEvent = Event;
/**
 * The shape of the payload for the ElementClick and ElementMouseOver events.
 * @public
 */
export interface ElementEventProps extends TriggerEventProps {
    event: 'ElementClick' | 'ElementMouseOver';
    /**
     * The CSS Selector of the element that was clicked or hovered over.
     */
    cssSelector: string;
    preventDefault?: boolean;
    /**
     * If the element had a default behavior, it will be delayed until the workflow is completed.
     */
    delayDefaultBehavior?: boolean;
}
/**
 * ElementEvents handles events fired off by a DOM element.
 * See https://developer.mozilla.org/en-US/docs/Web/API/Element#events
 */
export declare class ElementEventStrategy extends EventStrategy<ElementEventProps, ElementEvent> {
    private readonly domEvent;
    constructor(context: WorkflowContext, props: ElementEventProps);
    start(): void;
    private handleElementEvent;
}
//# sourceMappingURL=ElementEventStrategy.d.ts.map