"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
jest.mock('./EventStrategies');
var TriggerEvent_1 = require("./TriggerEvent");
var EventStrategies_1 = require("./EventStrategies");
var jest_mock_extended_1 = require("jest-mock-extended");
var factories_1 = require("../../__tests__/factories");
var mockedResolver = EventStrategies_1.EventStrategyResolver;
beforeEach(function () {
    // Clear all instances and calls to constructor and all methods:
    mockedResolver.mockClear();
});
describe('TriggerEvent', function () {
    var context = factories_1.contextFactory.build();
    var triggerEvent;
    var props = {
        id: 'test-id',
        event: 'PageView',
        urlPattern: 'https://samelogic.com/*/test'
    };
    var mockEventStrategy;
    beforeEach(function () {
        mockEventStrategy = (0, jest_mock_extended_1.mock)();
        mockedResolver.mockImplementation(function () {
            return { resolveStrategyByEventType: function () { return mockEventStrategy; } };
        });
    });
    describe('when started', function () {
        beforeEach(function () {
            triggerEvent = new TriggerEvent_1.TriggerEvent(context, props);
            triggerEvent.start();
        });
        it('should start the strategy', function () {
            expect(mockEventStrategy.start).toBeCalled();
        });
        describe('when event is triggered', function () {
            var eventData = {
                condition: true,
                props: props,
                data: { href: 'https://test' }
            };
            var onTriggerChangeMock = jest.fn();
            beforeEach(function () {
                var _a;
                triggerEvent.onChanged = onTriggerChangeMock;
                (_a = mockEventStrategy.onEventTriggered) === null || _a === void 0 ? void 0 : _a.call(mockEventStrategy, eventData);
            });
            it('should fire the onChanged event', function () {
                expect(onTriggerChangeMock).toBeCalledWith(eventData);
            });
        });
    });
});
//# sourceMappingURL=TriggerEvent.test.js.map