"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
jest.mock('../Triggers');
jest.mock('../Steps');
var WorkflowManager_1 = require("./WorkflowManager");
var Triggers_1 = require("../Triggers");
var Steps_1 = require("../Steps");
var jest_mock_extended_1 = require("jest-mock-extended");
var factories_1 = require("../__tests__/factories");
var mockedTriggerManager = Triggers_1.TriggerManager;
var mockedStepContainerManager = Steps_1.StepContainerManager;
beforeEach(function () {
    mockedStepContainerManager.mockClear();
    mockedTriggerManager.mockClear();
});
describe('WorkflowManager', function () {
    var workflowManager;
    var workflowConfig;
    var workflowContext;
    var packageMemoryCacheMock;
    var loggerMock;
    var eventLoggerMock;
    beforeEach(function () {
        workflowConfig = factories_1.workflowFactory.build();
        workflowContext = factories_1.contextFactory.build();
        packageMemoryCacheMock = (0, jest_mock_extended_1.mock)();
        loggerMock = (0, jest_mock_extended_1.mock)();
        eventLoggerMock = (0, jest_mock_extended_1.mock)();
        workflowManager = new WorkflowManager_1.WorkflowManager(workflowContext, workflowConfig, packageMemoryCacheMock, loggerMock, eventLoggerMock);
    });
    describe('start()', function () {
        var mockTriggerManagerInstance;
        var mockStepContainerManagerInstance;
        beforeEach(function () {
            mockTriggerManagerInstance = mockedTriggerManager.mock.instances[0];
            mockStepContainerManagerInstance = mockedStepContainerManager.mock.instances[0];
            workflowManager.start();
        });
        it('should start the TriggerManager', function () {
            expect(mockTriggerManagerInstance.start).toBeCalled();
        });
        describe('when trigger is fired', function () {
            beforeEach(function () {
                var _a;
                (_a = mockTriggerManagerInstance.onTriggered) === null || _a === void 0 ? void 0 : _a.call(mockTriggerManagerInstance);
            });
            it('should start the StepContainerManager', function () {
                // TODO: test that start is called with context.trigger event.
                expect(mockStepContainerManagerInstance.start).toBeCalled();
            });
        });
    });
});
//# sourceMappingURL=WorkflowManager.test.js.map